.. _api-cli:

vcs.cli
=======

.. automodule:: vcs.cli


.. command:: ExecutionManager

vcs.cli.ExecutionManager
------------------------

.. autoclass:: vcs.cli.ExecutionManager
   :members:


.. command:: BaseCommand

vcs.cli.BaseCommand
-------------------

.. autoclass:: vcs.cli.BaseCommand
   :members:



.. command:: RepositoryCommand

vcs.cli.RepositoryCommand
-------------------------

.. autoclass:: vcs.cli.RepositoryCommand
   :members:



.. command:: ChangesetCommand

vcs.cli.ChangesetCommand
------------------------

.. autoclass:: vcs.cli.ChangesetCommand
   :members:



.. command:: SingleChangesetCommand

vcs.cli.SingleChangesetCommand
------------------------------

.. autoclass:: vcs.cli.SingleChangesetCommand
   :members:
